bayespy.inference.vmp.nodes.gaussian.GaussianGammaDistribution.compute_fixed_moments_and_f
==========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaDistribution.compute_fixed_moments_and_f